summaryrefslogtreecommitdiffstats
path: root/k9author/newTitle.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'k9author/newTitle.cpp')
-rw-r--r--k9author/newTitle.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/k9author/newTitle.cpp b/k9author/newTitle.cpp
index e838b01..154e5ef 100644
--- a/k9author/newTitle.cpp
+++ b/k9author/newTitle.cpp
@@ -28,11 +28,11 @@
#include "klineedit.h"
/*
* Constructs a newTitle as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
-newTitle::newTitle( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+newTitle::newTitle( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
if ( !name )
setName( "newTitle" );
@@ -28,11 +28,11 @@
#include "klineedit.h"
/*
- * Constructs a newTitle as a child of 'tqparent', with the
+ * Constructs a newTitle as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/